@@ -35,8 +35,9 @@ use warnings;
 use base qw{ PPIx::Regexp::Structure };
 
 use Carp qw{ confess };
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.055';
+our $VERSION = '0.082';
 
 # Called by the lexer to record the capture number.
 sub __PPIX_LEXER__record_capture_number {
@@ -64,7 +65,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -72,7 +75,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
