@@ -36,7 +36,7 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.069';
+our $VERSION = '0.082';
 
 =begin comment
 
@@ -65,14 +65,14 @@ sub __defining_string {
 
 =cut
 
-__PACKAGE__->__setup_class(
-    {
-	'?|'	=> {
-	    expl	=> 'Re-use capture group numbers',
-	    intro	=> '5.009005',
-	},
+use constant DEF	=> {
+    '?|'	=> {
+	expl	=> 'Re-use capture group numbers',
+	intro	=> '5.009005',
     },
-);
+};
+
+__PACKAGE__->__setup_class();
 
 1;
 
@@ -81,7 +81,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -89,7 +91,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
