@@ -6,19 +6,24 @@ use strict;
 use warnings;
 
 use Carp;
-use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use PPIx::Regexp::Constant qw{
+    @CARP_NOT
+};
 use Scalar::Util qw{ blessed };
+use Text::Tabs ();
 
 use base qw{ Exporter };
 
 our @EXPORT_OK = qw{
     is_ppi_regexp_element
-    __choose_tokenizer_class __instance
+    __choose_tokenizer_class
+    __instance
     __is_ppi_regexp_element
-    __ns_can __to_ordinal_en
+    __ns_can
+    __to_ordinal_en
 };
 
-our $VERSION = '0.069';
+our $VERSION = '0.082';
 
 sub is_ppi_regexp_element {
     my ( $elem ) = @_;
@@ -160,7 +165,6 @@ representing its ordinal in English. For example
 
 =cut
 
-
 =head1 SEE ALSO
 
 L<Params::Util|Params::Util>, which I recommend, but in the case of
@@ -168,11 +172,12 @@ C<PPIx::Regexp> I did not want to introduce a dependency on an XS module
 when all I really wanted was the function of that module's
 C<_INSTANCE()> subroutine.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -180,7 +185,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2020 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
